@@ -72,8 +72,11 @@ class BaseWorker:
             jobs.append(
                 threading.Thread(target=partial(self.consumer.run, self._source))
             )
+        for i in jobs:
+            i.start()
         for i in jobs:
             i.join()
+            log.warning('Thread is done')
 
     def process(self, data: dict):
         try:
